@@ -20,17 +20,18 @@ class RequestsProKeywords(RequestsLibrary):
         self.timeout = 90
         self.verify = False
 
-    def trigger_api(self, test_data_full_path, test_input_path, api_name, base_url, **kwargs):
+    def trigger_api(self,
+                    test_data_full_path,
+                    test_input_path,
+                    api_name,
+                    base_url,
+                    auth=None):
 
         logger.info('*************************************************************************************************')
         logger.info('Trigger API using the parameters specified in test data sheet - ' + api_name)
         logger.info('*************************************************************************************************')
         logger.info('Step-01: Start - Read and filter test data sheet based on API_NAME')
         test_cases_df = pd.read_csv(str(test_data_full_path), dtype=str)
-        # test_cases_df = pd.read_csv(str(test_data_full_path), dytpe=str)
-        # Map the lowering function to all column names
-        # test_cases_df.columns = map(str.lower, test_cases_df.columns)
-
         selected_api_df = test_cases_df.loc[test_cases_df['test_name'] == api_name].copy()
         selected_api_df = selected_api_df.loc[selected_api_df['tbe'] == 'YES']
         selected_api_df = selected_api_df.reset_index(drop=True)
@@ -54,10 +55,14 @@ class RequestsProKeywords(RequestsLibrary):
         logger.info('Step-03: End   - Assign default values to None')
 
         logger.info('Step-04: Start - Assign project specific values')
-        if 'auth' in kwargs:
-            for key, value in kwargs.items():
-                if key == 'auth':
-                    auth = value
+        # Check if authorization is required
+        if auth is not None:
+            auth = auth.split(',')
+            logger.debug(auth)
+        elif pd.isna(selected_api_df.loc[0, 'auth']):
+            auth = None
+        else:
+            auth = str(selected_api_df['auth'].item()).split(',')
         logger.info('Step-04: End   - Assign project specific values')
 
         logger.info('Step-05: Start - Identify uri')
@@ -96,12 +101,6 @@ class RequestsProKeywords(RequestsLibrary):
             with open(test_input_path + api_name + '/' + file_name + '.JSON') as f:
                 data = json.load(f)
 
-        # Check if authorization is required
-        if pd.isna(selected_api_df.loc[0, 'auth']):
-            auth = None
-        else:
-            auth = str(selected_api_df['auth'].item()).split(',')
-
         # Check if headers is required
         headers = {}
         if pd.isna(selected_api_df.loc[0, 'headers']):
@@ -158,7 +157,7 @@ class RequestsProKeywords(RequestsLibrary):
                                                         auth=auth, timeout=timeout, proxies=proxies, verify=verify,
                                                         debug=debug, max_retries=max_retries,
                                                         backoff_factor=backoff_factor,
-                                                        disable_warnings=disable_warnings)
+                                                        disable_warnings=1)
             # Trigger Get method
             response = super(RequestsLibrary, self).get_request(alias=alias, uri=uri, headers=headers, json=data,
                                                                 params=params, allow_redirects=None, timeout=timeout)
@@ -175,7 +174,7 @@ class RequestsProKeywords(RequestsLibrary):
             response = super(RequestsLibrary, self).put_request(alias=alias, uri=uri, data=data, json=json_data,
                                                                 params=params, files=files, headers=headers,
                                                                 allow_redirects=None, timeout=timeout)
-        else:
+        elif request_type == 'POST':
             # Create Session
             super(RequestsLibrary, self).create_session(alias=alias, url=base_url, headers=headers, cookies=cookies,
                                                         auth=auth, timeout=timeout, proxies=proxies, verify=verify,
